@@ -111,3 +111,12 @@ class FinanceTransact(generics.UpdateAPIView):  # 或继承(APIView)
         if err_txt is None:
             return util_response(data=data)
         return util_response(err=47767, msg=err_txt)
+
+    # 核销
+    def invoicing_approval(self):
+        params = parse_data(self)
+        data, err_txt = FinanceTransactsService.invoicing_approval(params)
+        if err_txt is None:
+            return util_response(data=data)
+        return util_response(err=47767, msg=err_txt)
+
