@@ -14,7 +14,7 @@ from django.db.models import F
 from django.db.models import Sum, Count
 from decimal import Decimal
 import pytz
-from django.http import HttpResponse
+from django.http import HttpResponse, JsonResponse
 from django.utils.translation import gettext as _
 
 from ..models import *
@@ -27,6 +27,7 @@ logger = logging.getLogger(__name__)
 
 class FinanceTransacts(generics.UpdateAPIView):  # 或继承(APIView)
     """ REST framework的APIView实现获取card列表 """
+
     # authentication_classes = (TokenAuthentication,)  # token认证
     # permission_classes = (IsAuthenticated,)   # IsAuthenticated 仅通过认证的用户
     # permission_classes = (AllowAny,)  # 允许所有用户 (IsAuthenticated,IsStaffOrBureau)
@@ -62,4 +63,31 @@ class FinanceTransacts(generics.UpdateAPIView):  # 或继承(APIView)
             'data': data
         })
 
+    def get_finance_thread(self, *args, **kwargs):
+
+        # ========== 一、验证权限 ==========
+
+        token = self.META.get('HTTP_AUTHORIZATION', '')
+        if not token:
+            return util_response(err=4001, msg='缺少Token')
+
+        # print("get token:", token)
+        data, err_txt = UserService.check_token(token)
+        # print("get data, err_txt:", data, err_txt)
+        if not data:
+            return util_response(err=4002, msg=err_txt)
+
+        # ========== 二、必填性检查 ==========
+
+        params = parse_data(self)
+        data, err_txt = FinanceTransactsService.get_finance_thread(params, data['user_id'])
+        if not data:
+            return util_response(err=4002, msg=err_txt)
+
+        return JsonResponse({
+            'err': 0,
+            'msg': 'OK',
+            'data': data
+        })
+
         # return HttpResponse(output)
