@@ -114,7 +114,7 @@ class Transact(models.Model):
     balance = models.DecimalField(verbose_name='余额', max_digits=32, decimal_places=8, db_index=True, default=0)
     pay_mode = models.ForeignKey(verbose_name='支付方式', to=PayMode, db_column='pay_mode_id', on_delete=models.DO_NOTHING,
                                  unique=False, blank=True, null=True, default=5)
-    thread_id = models.BigIntegerField(verbose_name='资金id', blank=True, null=True,)
+    thread_id = models.BigIntegerField(verbose_name='资金id',  db_index=True, null=True, )
     goods_info = models.JSONField(verbose_name='商品信息', blank=True, null=True)
     pay_info = models.JSONField(verbose_name='付款信息', blank=True, null=True)
     remark = models.TextField(verbose_name='备注', blank=True, null=True)
