@@ -24,10 +24,17 @@ module_root = str(Path(__file__).resolve().parent)
 main_config_dict = JDict(JConfig.get_section(path=str(BASE_DIR) + "/config.ini", section="xj_payment"))
 module_config_dict = JDict(JConfig.get_section(path=str(BASE_DIR) + "/config.ini", section="xj_payment"))
 
+finance_main_config_dict = JDict(JConfig.get_section(path=str(BASE_DIR) + "/config.ini", section="xj_finance"))
+finance_module_config_dict = JDict(JConfig.get_section(path=str(BASE_DIR) + "/config.ini", section="xj_finance"))
+
 # 商户名称
 merchant_name = main_config_dict.merchant_name or module_config_dict.merchant_name or ""
 sub_appid = main_config_dict.wechat_merchant_app_id or module_config_dict.wechat_merchant_app_id or ""
 
+sand_box_meet = finance_main_config_dict.sand_box_meet or finance_module_config_dict.sand_box_meet or ""
+sand_box_receivable = finance_main_config_dict.sand_box_receivable or finance_module_config_dict.sand_box_receivable or ""
+sand_box_cash_withdrawal = finance_main_config_dict.sand_box_receivable or finance_module_config_dict.sand_box_cash_withdrawal or ""
+
 
 # 声明用户序列化
 class UserSerializer(serializers.ModelSerializer):
@@ -156,7 +163,7 @@ class FinanceTransactService:
             return None, '记录不存在'
 
         serializer = FinanceTransactSerializer(transact, many=False)
-        print(">>> serializer:", serializer)
+        # print(">>> serializer:", serializer)
 
         # # 翻译
         # output = _("Welcome to my site.")
@@ -172,6 +179,54 @@ class FinanceTransactService:
             return None, "不存在"
         return transact, None
 
+    @staticmethod
+    def finance_flow_writing(params, fund_type=None):
+
+        # meet_data['sand_box'] = sand_box_receivable  # 沙盒应收
+        # meet_data['transact_no'] = FinanceService.make_unicode(str(applicant_person_id))  # 流水号
+        # meet_data['amount'] = amount
+        # meet_data['account_id'] = applicant_person_id  # 报名人id
+        # meet_data['their_account_id'] = finance_transact_data['their_account_id']
+        # meet_data['order_no'] = order_no  # 订单号
+        # meet_data['currency_id'] = finance_transact_data['currency_id']  # 币种
+        # meet_data['pay_mode_id'] = finance_transact_data['pay_mode_id']  # 支付方式
+        # meet_data['platform_id'] = finance_transact_data['platform_id']  # 所属平台
+        # meet_data['summary'] = finance_transact_data['summary']  # 摘要说明
+        # meet_data['finance_status_code'] = 2  # 资金状态码 finance_status_code 242 报名成功 待付款
+        platform_finance_data = {}
+        user_finance_data = {}
+        if fund_type == "RECHARGE":
+            platform_finance_data['account_id'] = sub_appid  # 收款方
+            platform_finance_data['their_account_name'] = params['user_id']  # 付款方
+            finance_add_data, err_txt = FinanceTransactService.post(platform_finance_data)
+            if err_txt:
+                return None, err_txt
+            user_finance_data['account_id'] = params['user_id']  #
+            user_finance_data['their_account_name'] = sub_appid  # 付款方
+            user_add_data, user_err_txt = FinanceTransactService.post(platform_finance_data)
+            if user_err_txt:
+                return None, user_err_txt
+        elif fund_type == "PAY":
+            platform_finance_data['account_id'] = sub_appid  # 收款方
+            platform_finance_data['their_account_name'] = params['user_id']  # 付款方
+            platform_finance_data['sand_box'] = sand_box_meet  # 沙盒应付
+            finance_add_data, err_txt = FinanceTransactService.post(platform_finance_data)
+            if err_txt:
+                return None, err_txt
+            user_finance_data['account_id'] = params['user_id']  #
+            user_finance_data['their_account_name'] = sub_appid  # 付款方
+            user_finance_data['sand_box'] = sand_box_receivable  # 沙盒应收
+            user_add_data, user_err_txt = FinanceTransactService.post(platform_finance_data)
+            if user_err_txt:
+                return None, user_err_txt
+        elif fund_type == "WITHDRAW":
+            user_finance_data['account_id'] = params['user_id']  # 收款方
+            user_finance_data['their_account_name'] = sub_appid  # 付款方
+            user_finance_data['sand_box'] = sand_box_cash_withdrawal  # 提现
+            finance_add_data, err_txt = FinanceTransactService.post(user_finance_data)
+            if err_txt:
+                return None, None
+
     @staticmethod
     def post(param):
         item = serializer_params = {}  # 将要写入的某条数据
@@ -351,8 +406,8 @@ class FinanceTransactService:
 
         # 信息模块id
         thread_id = param.get('thread_id', '')
-        item['thread_id'] = thread_id
-
+        if thread_id:
+            item['thread_id'] = thread_id
         # 快照
         snapshot = param.get('snapshot', '')
         if snapshot:
