@@ -96,8 +96,8 @@ class FinanceTransactsSerializer(serializers.ModelSerializer):
             'opposite_account',
             'summary',
             'currency',
-            # 'income',
-            # 'outgo',
+            'income',
+            'outgo',
             'lend',
             'amount',
             'balance',
@@ -150,7 +150,7 @@ class FinanceTransactsService:
         # ========== 三、内容的类型准确性检查 ==========
 
         valid = FinanceService.check_filter_validity(params=params)
-        print(">>> check_filter_validity", valid)
+        # print(">>> check_filter_validity", valid)
         if valid['err'] > 0:
             # return Response({'err': valid['err'], 'msg': valid['msg'], })
             return None, valid['msg']
@@ -161,7 +161,7 @@ class FinanceTransactsService:
             transacts = transacts.filter(
                 transact_time__range=(params['transact_time_start'], params['transact_time_end']))
 
-        print(">>> transacts: ", transacts)
+        # print(">>> transacts: ", transacts)
 
         # statistic_list = []
         # aggr = transacts.aggregate(
@@ -272,7 +272,7 @@ class FinanceTransactsService:
     def distribution(params):
         order_no = params.get("order_no", "")
         applicant_person_id = params.get("applicant_person_id", "")
-        # payment_category = params.get("payment_category  ", "meet")  # 款项类目 receivable 应收 meet 应付
+        payment_category = params.get("payment_category  ", "meet")  # 款项类目 receivable 应收 meet 应付
         amount = params.get('amount', 0.0)  # 如果是负数是应付反之是应收
         two_level = params.get('two_level', "")  # 是否为二级分销
         receivable_data = {}  # 应收数据
@@ -432,6 +432,8 @@ class FinanceTransactsService:
 
     @staticmethod
     def get_finance_thread(params, user_id):
+        page = int(params['page']) - 1 if 'page' in params else 0
+        size = int(params['size']) if 'size' in params else 10
         transact_list, err = FinanceTransactsService.get(params, user_id)
         if err:
             return None, err
@@ -439,8 +441,16 @@ class FinanceTransactsService:
             result_list=transact_list['list'],
             alias_dict={"snapshot": "finance_snapshot"}
         )
-        print("transact_list", transact_list)
+        income = 0
+        outgo = 0
+        for i in transact_list['list']:
+            income += float(i['income'])
+            outgo += float(i['outgo'])
 
+        statistics = {
+            "income": income,
+            "outgo": outgo,
+        }
         thread_id_list = [item.get("thread_id", None) for item in transact_list['list']]
         # print("thread_id_list:", thread_id_list)
         thread_list, err = ThreadListService.search(thread_id_list)
@@ -451,7 +461,9 @@ class FinanceTransactsService:
         # print("data:", data)
         # print(thread_id_list)
         # total = transact.count()
-        return {'total': 0, 'list': data}, None
+        # return {'total': 0, 'list': data}, None
+        return {'size': int(size), 'page': int(page + 1), 'total': transact_list['total'], 'list': data,
+                "statistics": statistics}, None
         # return {'size': int(size), 'page': int(page + 1), 'total': total, 'list': thread_id_list}, None
 
     @staticmethod
